Dashboard use and FAQ
==========================

## What can I see in the Dashboard?

Publishers, in your Dashboard, you can see usage data for your own published works. You can see the usage of the books you have published in terms of views, downloads, and online mentions and events. You can also view which countries and institutions are using your books, and which subjects are represented in your collections. 

Features to explore:

* **Reset** - use the “Reset” button at the top of the page, or “Reset filters” to the right of the filters selection
* Search by **author name** (currently displayed as last name, first name) learn more in [ORCID’s documentation about first and last names](https://support.orcid.org/hc/en-us/articles/360006973853))
* **Track usage over time** - from the “Overview” page, see which month has the highest usage numbers when all book titles are selected
* See **usage for a specific title** - from the “Overview” page, select a book title from the filter and see the total access number
* See **usage across geographic regions** - from the “Global Reach” page, select a country from the country filter and see on the number of book downloads and the number of chapter downloads. Countries and territories are based on ISO standard 3166.

## I’m not yet participating, but can I see a demo?
You may view the [BAD template Dashboard](https://template.book-analytics.org/), powered by usage data from the University of Michigan Press which they have very kindly made publicly available, with no login details required.

## How should I interpret the data from the Dashboard?
Presenting a holistic view of usage information can be difficult, because ebooks can be hosted in multiple repositories and platforms, in different file formats (PDF, EPUB, MOBI, HTML), and in different levels (whole book or by chapter). Each repository provides book content to different audiences in different ways.

Before studying data from the Dashboard, we suggest that you take some time to understand the [data sources](dashboard_data.md), including the limitations of comparing different data sources. Learn more about how usage is influenced by the language of the work, its subject, its platform, and seasonal differences in Ronald’s [blog post](https://oapen.hypotheses.org/714) and research paper, “[Measured in a context: making sense of open access book data](https://doi.org/10.1629/uksg.627)”.

Caveats:
* For publishers with a smaller number of titles, it’s harder to see a pattern and understand why some get more downloads than others
* Incomplete data can hamper making accurate comparisons

But all that said, the Dashboard can help you explore some interesting questions!

Publishers, here are some questions the Dashboard data can help you consider:
* In which countries and territories are my publications most and least downloaded?
* Does this correspond to the languages in which I’m publishing?
* Which subjects are most or least popular in different areas?
* How does this change over time? 

